/*
 * Gimbal
 * Copyright (C) 2024 moonleay
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package net.moonleay.gimbal.client.config

import kotlinx.serialization.ExperimentalSerializationApi
import kotlinx.serialization.json.Json
import kotlinx.serialization.json.decodeFromStream
import kotlinx.serialization.json.encodeToStream
import java.nio.file.Path
import kotlin.io.path.*

class ClientConfigHolder(private val path: Path) {
    var config: GimbalClientConfig
        private set

    init {
        this.config = load()
    }

    fun updateConfig(new: GimbalClientConfig) {
        this.config = new
        this.save(config)
    }

    @OptIn(ExperimentalSerializationApi::class)
    fun load(): GimbalClientConfig {
        if (!path.isReadable())
            save(GimbalClientConfig())
        val iStream = path.inputStream()
        val gimbalClientConfig: GimbalClientConfig = iStream.use {
            Json {
                ignoreUnknownKeys = true
            }.decodeFromStream<GimbalClientConfig>(it)
        }
        iStream.close()
        return gimbalClientConfig
    }

    @OptIn(ExperimentalSerializationApi::class)
    fun save(conf: GimbalClientConfig) {
        if (!path.parent.exists()) {
            path.parent.createDirectory()
        }
        if (!path.parent.isWritable()) {
            throw Exception("Parent of path ${path.parent.pathString} is not writable.")
        }
        if (!path.exists())
            path.createFile()
        if (!path.isWritable()) {
            throw Exception("Path (${path.pathString}) exists, but is not writable.")
        }
        val oStream = path.outputStream()
        oStream.use {
            Json {
                ignoreUnknownKeys = true
            }.encodeToStream<GimbalClientConfig>(conf, it)
        }
        oStream.close()
    }

}
