/*
 * Gimbal
 * Copyright (C) 2024 moonleay
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package net.moonleay.gimbal.editor.util

import net.moonleay.gimbal.editor.state.EditorState
import net.moonleay.gimbal.editor.state.mode.Capability
import net.moonleay.gimbal.editor.state.mode.Mode
import net.moonleay.gimbal.editor.state.mode.ModeModifier


object EditorUtil {

    /*
    * Check if a player should be able to perform an action
    * */
    fun shouldPlayer(capability: Capability, state: EditorState): Boolean {
        when (capability) {
            Capability.INSERT -> {
                return state.editorMode == Mode.INSERT
            }

            Capability.REPLACE -> {
                return state.editorMode == Mode.REPLACE
            }

            Capability.CAN_INTERACT -> {
                return state.editorMode != Mode.VISUAL && state.editorMode != Mode.NORMAL
            }

            Capability.NO_CLIP -> {
                return state.editorModifier.contains(ModeModifier.NO_CLIP)
            }

            Capability.FORCE_PLACE -> {
                return state.editorModifier.contains(ModeModifier.FORCE_PLACE)
            }

            Capability.NO_UPDATES -> {
                return state.editorModifier.contains(ModeModifier.NO_UPDATES)
            }

            Capability.BULLDOZER -> {
                return state.editorModifier.contains(ModeModifier.BULLDOZER)
            }
        }
    }
}
